<?xml version="1.0" encoding="ISO-8859-1"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform">
	<!-- Modified by Kurris to use more tokens and properly output some char. info. -->
	<!-- E-Tools Stylesheet for export to Klooge.Werks Ver 0.99 beta-->
	<!-- Written by Daedalus with liberal code snippets from Trevor Salla's "Monster Page" Stylesheets that shipped with E-Tools. -->
	<!-- Known Issues:
		Empty elements denote areas where I was unable to find the data.
		Multiple Casting classes will cause problems, nature of the beast with Klooge for now ;-).
		Double weapons are not handled correctly in the output.
		Proper indentation is not occuring in the final xml document.  
	  
	To Do:
 		Any other reasonable suggestions that come along.
 		Clean-up so empty tags aren't output.
		 
 	Fixed in 0.91
		*	Fixed the + not getting attatched to the front of positive skill totals.
	Fixed in 0.92
		*	Removed the comma's from the next level field.
	Changed in 0.93
		*	Added math to calculate Icon Size.  IconSize = (XFace + YFace)/4
	Fixed in 0.94
		*	Fixed calculation of Attacks per round for characters with a Base Attack Value of 0.
	Fixed in 0.95
		*	Fixed Spell description imports so they do not load into the expression field.
		*	Load a default {0} into the expression field for spells so they do not apply the DC to damage.
		*	DR now imports as an integer value and is the sum of SQ and CF DR integers.
		*	Proper modifier is added to the Spell DC field for casters.
	Changed in 0.95
		*	Added Stat Modifier tokens to various places on the character sheet so temporary modifiers will
			automatically apply to various values.
		*	Weapons equipped in the off hand are now denoted with an (OH) beside their name.
 	Fixed in 0.96
 		*	Fixed a problem where class names with spaces could cause invalid output xml tags.
	Fixed in 0.97
		*	The Short Spell description no longer shows up in the 'Effect' column.
		*   Multi-Classed casters now work properly.
		*	Races with spell like abilities now have those abilities appear in the spell list.
		*	Added the IconSizeDivisor global for easy access.
		*	An empty tag is no longer output if spell resistance isn't present in the etools export.
	Changed in 0.98
		*	Added support for the spell description parser.
		*	Spell descriptions now have Klooge expressions added automatically.-->
		
	<xsl:import href="General String Functions"/>
	<xsl:import href="Stat Functions"/>
	<xsl:import href="WerksDescriptionParser"/>
	<xsl:output method="xml" version="1.0" encoding="iso-8859-1" indent="yes"/>
	<xsl:template match="/">
		<xsl:variable name="IconSizeDivisor" select="'4'"/>
		<xsl:element name="char-sheet-3rd-ed">
			<xsl:element name="personal-info">
				<xsl:element name="name">
					<xsl:value-of select="/character/name"/>
				</xsl:element>
				<xsl:element name="player">
					<xsl:value-of select="/character/player"/>
				</xsl:element>
				<xsl:element name="class">
					<xsl:value-of select="/character/classes/string"/>
				</xsl:element>
				<xsl:element name="race">
					<xsl:value-of select="/character/race"/>
				</xsl:element>
				<xsl:element name="type">
					<xsl:value-of select="/character/size/type"/>
				</xsl:element>
				<xsl:element name="size">
					<xsl:value-of select="/character/size/category"/>
				</xsl:element>
				<xsl:element name="alignment">
					<xsl:value-of select="/character/alignment/name"/>
				</xsl:element>
				<xsl:element name="age-sex">
					<xsl:value-of select="/character/age"/> / <xsl:value-of select="normalize-space(/character/gender)"/>
				</xsl:element>
				<xsl:element name="height-weight">
					<xsl:value-of select="/character/size/height"/> / <xsl:value-of select="normalize-space(/character/size/weight)"/>
				</xsl:element>
				<xsl:element name="hair-eyes">
					<xsl:value-of select="/character/hair"/> / <xsl:value-of select="normalize-space(/character/eyes)"/>
				</xsl:element>
				<xsl:element name="speed">
					<xsl:for-each select="//character/speeds/speed">
						<xsl:if test="position() &gt; 1">
							<xsl:text>, </xsl:text>
						</xsl:if>
						<xsl:choose>
							<xsl:when test="name = 'Base'">
								<xsl:text>Base: </xsl:text>
								<xsl:value-of select="value"/>
							</xsl:when>
							<xsl:otherwise>
								<xsl:value-of select="name"/>
								<xsl:text> </xsl:text>
								<xsl:value-of select="value"/>
							</xsl:otherwise>
						</xsl:choose>
					</xsl:for-each>
				</xsl:element>
				<xsl:element name="cr">
					<xsl:value-of select="/character/classes/total"/>
				</xsl:element>
				<xsl:element name="hit-dice">
					<xsl:for-each select="/character/hit-dice/hit-die">
						<xsl:value-of select="die"/>
						<xsl:value-of select="bonus"/>
						<xsl:choose>
							<xsl:when test="position() != last()">
								<xsl:text>; </xsl:text>
							</xsl:when>
						</xsl:choose>
					</xsl:for-each>
				</xsl:element>
				<xsl:element name="experience">
					<xsl:value-of select="/character/experience"/>
				</xsl:element>
				<xsl:element name="next-level">
					<xsl:variable name="totallevel" select="/character/classes/total"/>
					<xsl:variable name="nextlevel" select="($totallevel * $totallevel + $totallevel) * 500"/>
					<xsl:value-of select="format-number($nextlevel, '########0')"/>
				</xsl:element>
			</xsl:element>
			<xsl:element name="level-info">
				<xsl:element name="level">
					<xsl:value-of select="/character/classes/total"/>
				</xsl:element>
				<xsl:for-each select="/character/classes/class">
					<xsl:variable name="currclass" select="translate(name, ' ','')"/>
					<xsl:variable name="classtag" select="concat($currclass, '-level')"/>
					<xsl:variable name="lclasstag">
						<xsl:call-template name="to-lower">
							<xsl:with-param name="text" select="$classtag"/>
						</xsl:call-template>
					</xsl:variable>
					<xsl:element name="{$lclasstag}">
						<xsl:value-of select="level"/>
					</xsl:element>
				</xsl:for-each>
			</xsl:element>
			<xsl:element name="combat">
				<xsl:element name="cur-hit-points">
					<xsl:value-of select="/character/hit-points"/>
				</xsl:element>
				<xsl:element name="max-hit-points">
					<xsl:value-of select="/character/hit-points"/>
				</xsl:element>
				<xsl:element name="subdual-damage">
					<xsl:text>0</xsl:text>
				</xsl:element>
				<xsl:variable name="DamageReductionSQ">
					<xsl:for-each select="/character/features/special-qualities/special-quality">
						<xsl:variable name="SQ" select="."/>
						<xsl:if test="starts-with($SQ, 'Damage Reduction')">
							<xsl:value-of select="normalize-space(substring-before(substring-after($SQ, ': '), '/'))"/>
						</xsl:if>
					</xsl:for-each>
				</xsl:variable>
				<xsl:variable name="DamageReductionCF">
					<xsl:for-each select="/character/features/class-features/class-feature/feature">
						<xsl:variable name="CF" select="."/>
						<xsl:if test="starts-with($CF, 'Damage Reduction')">
							<xsl:value-of select="normalize-space(substring-before(substring-after($CF, 'Reduction '), '/'))"/>
						</xsl:if>
					</xsl:for-each>
				</xsl:variable>
				<xsl:choose>
					<xsl:when test="$DamageReductionSQ != ''">
						<xsl:choose>
							<xsl:when test="$DamageReductionCF != ''">
							    <xsl:element name="damage-reduction">
								<xsl:value-of select="$DamageReductionSQ + $DamageReductionCF"/>
							    </xsl:element>
							</xsl:when>
							<xsl:otherwise>
							    <xsl:element name="damage-reduction">
								<xsl:value-of select="$DamageReductionSQ"/>
							    </xsl:element>
							</xsl:otherwise>
						</xsl:choose>
					</xsl:when>
					<xsl:otherwise>
						<xsl:choose>
							<xsl:when test="$DamageReductionCF != ''">
							    <xsl:element name="damage-reduction">
								<xsl:value-of select="$DamageReductionCF"/>
							    </xsl:element>
							</xsl:when>
						</xsl:choose>
					</xsl:otherwise>
				</xsl:choose>
				<xsl:element name="base-attack-bonus">
					<xsl:value-of select="/character/attacks/base"/>
				</xsl:element>
				<xsl:element name="atks-per-round">
					<xsl:variable name="BaB" select="substring-after(/character/attacks/base, '+')"/>
					<xsl:variable name="NumAtk" select="$BaB div 5"/>
					<xsl:variable name="Remainder" select="$BaB mod 5"/>
					<xsl:choose>
						<xsl:when test="$Remainder &gt; 0">
							<xsl:value-of select="floor($NumAtk) + 1"/>
						</xsl:when>
						<xsl:otherwise>
							<xsl:choose>
								<xsl:when test="floor($NumAtk) = 0">
									<xsl:value-of select="'1'"/>
								</xsl:when>
								<xsl:otherwise>
									<xsl:value-of select="floor($NumAtk)"/>
								</xsl:otherwise>
							</xsl:choose>
						</xsl:otherwise>
					</xsl:choose>
				</xsl:element>
			</xsl:element>
			<xsl:element name="armor">
				<xsl:variable name="MaxDex">
					<xsl:variable name="TmpMaxDex">
						<xsl:variable name="LdCarried" select="//character/load/carried"/>
						<xsl:variable name="LdMedium" select="normalize-space(substring-after(//character/load/light, '-'))"/>
						<xsl:variable name="LdHeavy" select="normalize-space(substring-after(//character/load/medium, '-'))"/>
						<xsl:choose>
							<xsl:when test="$LdCarried &gt; $LdHeavy">
								<xsl:value-of select="1"/>
							</xsl:when>
							<xsl:when test="$LdCarried &gt; $LdMedium">
								<xsl:value-of select="3"/>
							</xsl:when>
							<xsl:otherwise>
								<xsl:value-of select="5678"/>
							</xsl:otherwise>
						</xsl:choose>
					</xsl:variable>
					<xsl:variable name="ArmorMaxDex" select="//character/equiped-items/armor/max-dex"/>
					<xsl:choose>
						<xsl:when test="$ArmorMaxDex != ''">
							<xsl:choose>
								<xsl:when test="$ArmorMaxDex &lt; $TmpMaxDex">
									<xsl:value-of select="$ArmorMaxDex"/>
								</xsl:when>
								<xsl:otherwise>
									<xsl:value-of select="$TmpMaxDex"/>
								</xsl:otherwise>
							</xsl:choose>
						</xsl:when>
						<xsl:otherwise>
							<xsl:value-of select="$TmpMaxDex"/>
						</xsl:otherwise>
					</xsl:choose>
				</xsl:variable>
				<xsl:element name="base-ac">
					<xsl:value-of select="(/character/armor-class/modifiers/modifier[@name = 'natural']/@value)+10"/>
				</xsl:element>
				<xsl:element name="armor-modifier">
					<xsl:value-of select="/character/armor-class/modifiers/modifier[@name = 'armor']/@value"/>
				</xsl:element>
				<xsl:element name="shield-modifier">
					<xsl:value-of select="/character/armor-class/modifiers/modifier[@name = 'shield']/@value"/>
				</xsl:element>
				<xsl:element name="dex-modifier">
					<xsl:value-of select="/character/armor-class/modifiers/modifier[@name = 'ability']/@value"/>
				</xsl:element>
				<xsl:element name="size-modifier">
					<xsl:value-of select="/character/armor-class/modifiers/modifier[@name = 'size']/@value"/>
				</xsl:element>
				<xsl:element name="misc-magic-modifier">
					<xsl:value-of select="/character/armor-class/modifiers/modifier[@name = 'misc']/@value"/>
				</xsl:element>
				<xsl:element name="ac-final">
					<xsl:value-of select="sum(/character/armor-class/modifiers/modifier[@name != 'misc']/@value)-(/character/armor-class/modifiers/modifier[@name = 'ability']/@value)"/>
					<xsl:choose>
						<xsl:when test="$MaxDex = '5678'">
							<xsl:text>$D</xsl:text>
						</xsl:when>
						<xsl:otherwise>
							<xsl:text>+($D:</xsl:text>
							<xsl:value-of select="$MaxDex"/>
							<xsl:text>)</xsl:text>
						</xsl:otherwise>
					</xsl:choose>
				</xsl:element>
				<xsl:for-each select="/character/features/special-qualities/special-quality">
					<xsl:variable name="SQ" select="."/>
					<xsl:if test="starts-with($SQ, 'Spell Resistance')">
						<xsl:element name="spell-resistance">
							<xsl:value-of select="substring-after($SQ, ': ')"/>
						</xsl:element>
					</xsl:if>
				</xsl:for-each>
				<xsl:element name="touch-ac">
					<xsl:value-of select="sum(/character/armor-class/modifiers/modifier[@name != 'misc']/@value)-(/character/armor-class/modifiers/modifier[@name = 'armor']/@value)-(/character/armor-class/modifiers/modifier[@name = 'shield']/@value)-(/character/armor-class/modifiers/modifier[@name = 'natural']/@value)-(/character/armor-class/modifiers/modifier[@name = 'ability']/@value)"/>
					<xsl:choose>
						<xsl:when test="$MaxDex = '5678'">
							<xsl:text>$D</xsl:text>
						</xsl:when>
						<xsl:otherwise>
							<xsl:text>+($D:</xsl:text>
							<xsl:value-of select="$MaxDex"/>
							<xsl:text>)</xsl:text>
						</xsl:otherwise>
					</xsl:choose>
				</xsl:element>
				<xsl:element name="flat-footed-ac">
					<xsl:value-of select="sum(/character/armor-class/modifiers/modifier[@name != 'misc']/@value)-(/character/armor-class/modifiers/modifier[@name = 'ability']/@value)"/>
				</xsl:element>
			</xsl:element>
			<xsl:element name="abilities">
				<xsl:for-each select="/character/abilities/ability">
					<xsl:variable name="currabil" select="abbr"/>
					<xsl:variable name="lcurrabil">
						<xsl:call-template name="to-lower">
							<xsl:with-param name="text" select="$currabil"/>
						</xsl:call-template>
					</xsl:variable>
					<xsl:element name="{$lcurrabil}">
						<xsl:value-of select="base"/>
					</xsl:element>
					<xsl:element name="{concat($lcurrabil, '-mod')}">
						<xsl:value-of select="modifier"/>
					</xsl:element>
				</xsl:for-each>
			</xsl:element>
			<xsl:element name="saving-throws">
				<xsl:for-each select="/character/saving-throws/saving-throw">
					<xsl:variable name="currsave" select="abbr"/>
					<xsl:variable name="lcurrsave">
						<xsl:call-template name="to-lower">
							<xsl:with-param name="text" select="$currsave"/>
						</xsl:call-template>
					</xsl:variable>
					<xsl:element name="{$lcurrsave}">
						<xsl:variable name="saveval" select="sum(modifiers/modifier[@name != 'misc']/@value)-(modifiers/modifier[@name = 'ability']/@value)"/>
						<xsl:if test="$saveval >= 0">
							<xsl:text>+</xsl:text>
						</xsl:if>
						<xsl:value-of select="$saveval"/>
						<xsl:choose>
							<xsl:when test="ability = 'Str'">
								<xsl:text>$S</xsl:text>
							</xsl:when>
							<xsl:when test="ability = 'Dex'">
								<xsl:text>$D</xsl:text>
							</xsl:when>
							<xsl:when test="ability = 'Con'">
								<xsl:text>$C</xsl:text>
							</xsl:when>
							<xsl:when test="ability = 'Int'">
								<xsl:text>$I</xsl:text>
							</xsl:when>
							<xsl:when test="ability = 'Wis'">
								<xsl:text>$W</xsl:text>
							</xsl:when>
							<xsl:when test="ability = 'Cha'">
								<xsl:text>$CH</xsl:text>
							</xsl:when>
						</xsl:choose>
					</xsl:element>
				</xsl:for-each>
				<xsl:element name="init">
					<xsl:variable name="initval" select="sum(/character/initiative/modifiers/modifier[@name != 'misc']/@value)-(/character/initiative/modifiers/modifier[@name = 'ability']/@value)"/>
					<xsl:if test="$initval >= 0">
						<xsl:text>+</xsl:text>
					</xsl:if>
					<xsl:value-of select="$initval"/>
					<xsl:text>$D</xsl:text>
				</xsl:element>
			</xsl:element>
			<xsl:element name="misc-attributes">
				<xsl:element name="threatened-area">
					<xsl:value-of select="/character/size/reach"/>
				</xsl:element>
				<xsl:element name="icon-size">
					<xsl:variable name="IcnXSize" select="/character/size/face/x"/>
					<xsl:variable name="IcnYSize" select="/character/size/face/y"/>
					<xsl:variable name="IcnSize" select="($IcnXSize + $IcnYSize) div $IconSizeDivisor"/>
					<xsl:value-of select="$IcnSize"/>
				</xsl:element>
			</xsl:element>
			<xsl:element name="racial-traits">
				<xsl:for-each select="/character/features/race-features/race-feature">
					<xsl:sort select="." order="ascending"/>
					<xsl:element name="racial-trait">
						<xsl:element name="trait-name">
							<xsl:value-of select="."/>
						</xsl:element>
					</xsl:element>
				</xsl:for-each>
			</xsl:element>
			<xsl:element name="languages">
				<xsl:for-each select="/character/languages/language">
					<xsl:sort select="." order="ascending"/>
					<xsl:element name="language">
						<xsl:element name="lang-name">
							<xsl:value-of select="."/>
						</xsl:element>
					</xsl:element>
				</xsl:for-each>
			</xsl:element>
			<xsl:element name="feats">
				<xsl:for-each select="/character/features/feats/feat">
					<xsl:sort select="name" order="ascending"/>
					<xsl:element name="feat">
						<xsl:element name="feat-name">
							<xsl:value-of select="name"/>
						</xsl:element>
					</xsl:element>
				</xsl:for-each>
			</xsl:element>
			<xsl:element name="skills">
				<xsl:for-each select="/character/skills/skill">
					<xsl:sort select="name" order="ascending"/>
					<xsl:element name="skill">
						<xsl:element name="skill-name">
							<xsl:value-of select="name"/>
						</xsl:element>
						<xsl:element name="total">
							<xsl:variable name="CSkillTot" select="sum(modifiers/modifier[@name != 'misc']/@value) - (modifiers/modifier[@name = 'ability']/@value)"/>
							<xsl:if test="$CSkillTot &gt; -1">
								<xsl:text>+</xsl:text>
							</xsl:if>
							<xsl:value-of select="sum(modifiers/modifier[@name != 'misc']/@value) - modifiers/modifier[@name = 'ability']/@value"/>
							<xsl:choose>
								<xsl:when test="ability = 'Str'">
									<xsl:text>$S</xsl:text>
								</xsl:when>
								<xsl:when test="ability = 'Dex'">
									<xsl:text>$D</xsl:text>
								</xsl:when>
								<xsl:when test="ability = 'Con'">
									<xsl:text>$C</xsl:text>
								</xsl:when>
								<xsl:when test="ability = 'Int'">
									<xsl:text>$I</xsl:text>
								</xsl:when>
								<xsl:when test="ability = 'Wis'">
									<xsl:text>$W</xsl:text>
								</xsl:when>
								<xsl:when test="ability = 'Cha'">
									<xsl:text>$CH</xsl:text>
								</xsl:when>
							</xsl:choose>
						</xsl:element>
						<xsl:element name="rank">
							<xsl:value-of select="modifiers/modifier[@name = 'rank']/@value"/>
						</xsl:element>
						<xsl:element name="modifier">
							<xsl:value-of select="modifiers/modifier[@name = 'ability']/@value"/>
						</xsl:element>
						<xsl:element name="misc">
							<xsl:value-of select="modifiers/modifier[@name = 'misc']/@value"/>
						</xsl:element>
						<xsl:element name="ability">
							<xsl:value-of select="ability"/>
						</xsl:element>
					</xsl:element>
				</xsl:for-each>
			</xsl:element>
			<xsl:element name="weapons">
				<xsl:for-each select="//character/equiped-items/weapons">
					<xsl:for-each select="weapon">
						<xsl:sort select="name" order="ascending"/>
						<xsl:choose>
							<xsl:when test="position() = 1">
								<xsl:call-template name="GenerateWeaponData">
									<xsl:with-param name="IsOffHand" select="'False'"/>
								</xsl:call-template>
							</xsl:when>
							<xsl:otherwise>
								<xsl:choose>
									<xsl:when test="//character/options/text-offhand-indication = 1">
										<xsl:call-template name="GenerateWeaponData">
											<xsl:with-param name="IsOffHand" select="'True'"/>
										</xsl:call-template>
									</xsl:when>
									<xsl:otherwise>
										<xsl:call-template name="GenerateWeaponData">
											<xsl:with-param name="IsOffHand" select="'False'"/>
										</xsl:call-template>
									</xsl:otherwise>
								</xsl:choose>
							</xsl:otherwise>
						</xsl:choose>
					</xsl:for-each>
				</xsl:for-each>
			</xsl:element>
			<xsl:element name="equipment">
				<xsl:for-each select="/character/items/item">
					<xsl:sort select="type" order="ascending"/>
					<xsl:element name="item">
						<xsl:element name="equip-name">
							<xsl:value-of select="type"/>
							<xsl:text>: </xsl:text>
							<xsl:value-of select="name"/>
						</xsl:element>
						<xsl:element name="desc">
							<xsl:text>Weight: </xsl:text>
							<xsl:value-of select="weight"/>
						</xsl:element>
					</xsl:element>
				</xsl:for-each>
			</xsl:element>
			<xsl:element name="wealth">
				<xsl:for-each select="/character/currency/*">
					<xsl:element name="coin">
						<xsl:element name="type">
							<xsl:value-of select="name()"/>
						</xsl:element>
						<xsl:element name="carried">
							<xsl:value-of select="."/>
						</xsl:element>
					</xsl:element>
				</xsl:for-each>
			</xsl:element>
			<xsl:element name="magic-abilities">
				<xsl:for-each select="/character/features/special-attacks/special-attack">
					<xsl:if test="name = 'Spell-like Abilities'">
						<xsl:for-each select="spell">
						<xsl:sort select="name" order="ascending"/>
							<xsl:element name="spell-levels">
								<xsl:element name="level">
									<xsl:value-of select="concat(name, '(Sp)')"/>
								</xsl:element>
								<xsl:choose>
									<xsl:when test="times-per-day = 'At Will'">
										<xsl:element name="max">
											<xsl:value-of select="times-per-day"/>
										</xsl:element>
										<xsl:element name="current">
											<xsl:value-of select="1"/>
										</xsl:element>
									</xsl:when>
									<xsl:otherwise>
										<xsl:element name="max">
											<xsl:value-of select="times-per-day"/>
										</xsl:element>
										<xsl:element name="current">
											<xsl:value-of select="times-per-day"/>
										</xsl:element>
									</xsl:otherwise>
								</xsl:choose>
							</xsl:element>
						</xsl:for-each>
					</xsl:if>
				</xsl:for-each>
				<xsl:for-each select="/character/spells-known/class">
					<xsl:variable name="CurrClassName" select="full-name"/>
					<xsl:for-each select="spells-per-day/level">
						<xsl:variable name="CSLevel" select="./@name"/>
						<xsl:variable name="BnsSpells" select="/character/spells-known/class[full-name = $CurrClassName]/bonus-spells-per-day/level[@name = $CSLevel]/@value"/>
						<xsl:variable name="TotSpells" select="@value + $BnsSpells"/>
						<xsl:element name="spell-levels">
							<xsl:element name="level">
								<xsl:choose>
									<xsl:when test="$CSLevel = '0'">
										<xsl:value-of select="concat($CurrClassName, ' ', $CSLevel)"/>
									</xsl:when>
									<xsl:otherwise>
										<xsl:value-of select="concat($CurrClassName, ' ', (substring($CSLevel,1,(string-length($CSLevel) - 2))))"/>
									</xsl:otherwise>
								</xsl:choose>
							</xsl:element>
							<xsl:element name="max">
								<xsl:value-of select="$TotSpells"/>
							</xsl:element>
							<xsl:element name="current">
								<xsl:value-of select="$TotSpells"/>
							</xsl:element>
						</xsl:element>
					</xsl:for-each>
				</xsl:for-each>
			</xsl:element>
			<xsl:choose>
				<xsl:when test="//character/equiped-items/armor/spell-failure and //character/equiped-items/shield/spell-failure">
				    <xsl:element name="spell-fail">
					<xsl:value-of select="//character/equiped-items/armor/spell-failure + //character/equiped-items/shield/spell-failure"/>
				    </xsl:element>
				</xsl:when>
				<xsl:when test="//character/equiped-items/armor/spell-failure and not(//character/equiped-items/shield/spell-failure)">
					<xsl:element name="spell-fail">
					    <xsl:value-of select="//character/equiped-items/armor/spell-failure"/>
					</xsl:element>
				</xsl:when>
				<xsl:when test="//character/equiped-items/shield/spell-failure and not(//character/equiped-items/armor/spell-failure)">
					<xsl:element name="spell-fail">
					    <xsl:value-of select="//character/equiped-items/shield/spell-failure"/>
					</xsl:element>
				</xsl:when>
			</xsl:choose>
			<xsl:element name="spell-dc">
				<xsl:variable name="CastClass" select="/character/spells-known/class/full-name"/>
				<xsl:choose>
					<xsl:when test="$CastClass = 'Bard'">
						<xsl:text>$Ch</xsl:text>
					</xsl:when>
					<xsl:when test="$CastClass = 'Cleric'">
						<xsl:text>$W</xsl:text>
					</xsl:when>
					<xsl:when test="$CastClass = 'Paladin'">
						<xsl:text>$W</xsl:text>
					</xsl:when>
					<xsl:when test="$CastClass = 'Ranger'">
						<xsl:text>$W</xsl:text>
					</xsl:when>
					<xsl:when test="$CastClass = 'Druid'">
						<xsl:text>$W</xsl:text>
					</xsl:when>
					<xsl:when test="$CastClass = 'Sorcerer'">
						<xsl:text>$Ch</xsl:text>
					</xsl:when>
					<xsl:when test="$CastClass = 'Wizard'">
						<xsl:text>$I</xsl:text>
					</xsl:when>
				</xsl:choose>
			</xsl:element>
			<xsl:element name="spells">
				<xsl:for-each select="/character/features/special-attacks/special-attack">
					<xsl:if test="name = 'Spell-like Abilities'">
						<xsl:for-each select="spell">
						<xsl:sort select="name" order="ascending"/>
							<xsl:element name="spell">
								<xsl:element name="spell-name">
									<xsl:value-of select="concat(name, '(Sp)')"/>
								</xsl:element>
								<xsl:element name="level">
									<xsl:value-of select="caster-level"/>
								</xsl:element>
								<xsl:element name="cast-level">
									<xsl:value-of select="concat(name, '(Sp)')"/>
								</xsl:element>
								<xsl:element name="expr">
									<xsl:value-of select="'{0}'"/>
								</xsl:element>
								<xsl:element name="num-memorized">
							    	<xsl:value-of select="'--'"/>
								</xsl:element>
								<xsl:element name="cost">
									<xsl:value-of select="'1'"/>
								</xsl:element>
							</xsl:element>
						</xsl:for-each>
					</xsl:if>
				</xsl:for-each>
				<xsl:for-each select="/character/spells-known/class">
					<xsl:variable name="CurrClassName" select="full-name"/>
					<xsl:variable name="CurrName" select="name"/>
					<xsl:for-each select="spell">
						<xsl:sort select="level" order="ascending"/>
						<xsl:sort select="name" order="ascending"/>
						<xsl:variable name="CSName" select="name"/>
						<xsl:element name="spell">
							<xsl:element name="spell-name">
								<xsl:value-of select="name"/>
							</xsl:element>
							<xsl:variable name="CurrSpell" select="name"/>
							<xsl:element name="level">
								<xsl:value-of select="level"/>
							</xsl:element>
							<xsl:element name="cast-level">
								<xsl:value-of select="concat($CurrClassName, ' ', level)"/>
							</xsl:element>
							<xsl:element name="expr">
								<xsl:variable name="SpDesc" select="/character/spells/spell[name=$CurrSpell]/short-description"/>
								<xsl:variable name="CLStr">
									<xsl:choose>
										<xsl:when test="$CurrClassName = 'Bard'">
											<xsl:value-of select="'$BAL'"/>
										</xsl:when>
										<xsl:when test="$CurrClassName = 'Cleric'">
											<xsl:value-of select="'$CL'"/>
										</xsl:when>
										<xsl:when test="$CurrClassName = 'Druid'">
											<xsl:value-of select="'$DL'"/>
										</xsl:when>
										<xsl:when test="$CurrClassName = 'Loremaster'">
											<xsl:value-of select="'$LML'"/>
										</xsl:when>
										<xsl:when test="$CurrClassName = 'Paladin'">
											<xsl:value-of select="'($PL*0.5)'"/>
										</xsl:when>
										<xsl:when test="$CurrClassName = 'Ranger'">
											<xsl:value-of select="'($RL*0.5)'"/>
										</xsl:when>
										<xsl:when test="$CurrClassName = 'Sorcerer'">
											<xsl:value-of select="'$SORL'"/>
										</xsl:when>
										<xsl:when test="$CurrClassName = 'Wizard'">
											<xsl:value-of select="'$WL'"/>
										</xsl:when>
										<xsl:otherwise>
											<xsl:value-of select="'??'"/>
										</xsl:otherwise>
									</xsl:choose>
								</xsl:variable>
								<xsl:call-template name="TokenizeSpellDesc">
									<xsl:with-param name="SpellDesc" select="$SpDesc"/>
									<xsl:with-param name="StartIndex" select="1"/>
									<xsl:with-param name="CasterLevel" select="$CLStr"/>
								</xsl:call-template>
							</xsl:element>
							<xsl:element name="num-memorized">
								<xsl:choose>
									<xsl:when test="$CurrClassName != 'Sorcerer'">
								    	<xsl:variable name="NormCount" select="/character/spells-prepared/class[name = $CurrName]/spell[name = $CurrSpell]/count"/>
								    	<xsl:variable name="SchoolCount" select="/character/spells-prepared/class[name = $CurrName]/spell[name = concat($CurrSpell, ' (s)')]/count"/>
								    	<xsl:choose>
								    		<xsl:when test="$NormCount &gt; 0 and $SchoolCount &gt; 0">
								    			<xsl:value-of select="$NormCount + $SchoolCount"/>
								    		</xsl:when>
								    		<xsl:when test="$NormCount &gt; 0">
								    			<xsl:value-of select="$NormCount"/>
								    		</xsl:when>
								    		<xsl:when test="$SchoolCount &gt; 0">
								    			<xsl:value-of select="$SchoolCount"/>
								    		</xsl:when>
								    		<xsl:otherwise>
												<xsl:value-of select="number('0')"/>
								    		</xsl:otherwise>
								    	</xsl:choose>
								    </xsl:when>
								    <xsl:otherwise>
								    	<xsl:value-of select="'--'"/>
								    </xsl:otherwise>
							    </xsl:choose>
							</xsl:element>
							<xsl:element name="cost">
								<xsl:value-of select="'1'"/>
							</xsl:element>
						</xsl:element>
					</xsl:for-each>
				</xsl:for-each>
			</xsl:element>
			<xsl:element name="notes">
				<xsl:element name="note">
					<xsl:element name="title">
						<xsl:value-of select="'Load Information'"/>
					</xsl:element>
					<xsl:element name="text">
						<xsl:for-each select="/character/load/*">
							<xsl:value-of select="name()"/>
							<xsl:text>: </xsl:text>
							<xsl:value-of select="."/>
							<xsl:value-of select="$cr"/>
						</xsl:for-each>
					</xsl:element>
				</xsl:element>
				<xsl:for-each select="/character/notes/*">
					<xsl:element name="note">
						<xsl:element name="title">
							<xsl:value-of select="name()"/>
						</xsl:element>
						<xsl:element name="text">
							<xsl:value-of select="."/>
						</xsl:element>
					</xsl:element>
				</xsl:for-each>
			</xsl:element>
		</xsl:element>
	</xsl:template>
	<xsl:template name="GenerateWeaponData">
		<xsl:param name="IsOffHand"/>
		<xsl:choose>
			<xsl:when test="$IsOffHand = 'True'">
				<xsl:element name="weapon">
					<xsl:element name="w-name">
						<xsl:value-of select="name"/>
						<xsl:text> (OH)</xsl:text>
					</xsl:element>
					<xsl:element name="hand">
						<xsl:value-of select="use-type"/>
					</xsl:element>
					<xsl:element name="atk-mod">
						<xsl:choose>
							<xsl:when test="type = 'Ranged'">
								<xsl:variable name="WpnBns">
									<xsl:choose>
										<xsl:when test="substring(bonus,1,1) = '+'">
											<xsl:value-of select="substring-after(bonus,'+')"/>
										</xsl:when>
										<xsl:otherwise>
											<xsl:value-of select="bonus"/>
										</xsl:otherwise>
									</xsl:choose>
								</xsl:variable>
								<xsl:variable name="AtkNoDex" select="(number($WpnBns)-//character/attacks/ranged/modifiers/modifier[@name = 'ability']/@value)"/>
								<xsl:call-template name="GenerateAttackString">
									<xsl:with-param name="WpnBonus" select="$AtkNoDex"/>
									<xsl:with-param name="BaseBonus" select="'0'"/>
									<xsl:with-param name="KloogeStat" select="'$D'"/>
								</xsl:call-template>
							</xsl:when>
							<xsl:otherwise>
								<xsl:variable name="WpnBns">
									<xsl:choose>
										<xsl:when test="substring(bonus,1,1) = '+'">
											<xsl:value-of select="substring-after(bonus,'+')"/>
										</xsl:when>
										<xsl:otherwise>
											<xsl:value-of select="bonus"/>
										</xsl:otherwise>
									</xsl:choose>
								</xsl:variable>
								<xsl:variable name="AtkNoStr" select="(number($WpnBns)-//character/attacks/melee/modifiers/modifier[@name = 'ability']/@value)"/>
								<xsl:call-template name="GenerateAttackString">
									<xsl:with-param name="WpnBonus" select="$AtkNoStr"/>
									<xsl:with-param name="BaseBonus" select="'0'"/>
									<xsl:with-param name="KloogeStat" select="'$S'"/>
								</xsl:call-template>
							</xsl:otherwise>
						</xsl:choose>
					</xsl:element>
					<xsl:element name="damage">
						<xsl:choose>
							<xsl:when test="contains(name,'bow')">
								<xsl:choose>
									<xsl:when test="contains(name,'Cross')">
										<xsl:value-of select="damage"/>
									</xsl:when>
									<xsl:otherwise>
										<xsl:choose>
											<xsl:when test="contains(name, 'Str')">
												<xsl:variable name="TempStr" select="substring-before(name, 'Str')"/>
												<xsl:variable name="MaxStr" select="normalize-space(substring-after($TempStr, '+'))"/>
												<xsl:variable name="WName" select="name"/>
												<xsl:value-of select="//character/items/item[name = $WName]/damage"/>
												<xsl:text>+(($S:</xsl:text>
												<xsl:value-of select="$MaxStr"/>
												<xsl:text>)*.5)</xsl:text>
											</xsl:when>
											<xsl:otherwise>
												<xsl:variable name="WName" select="name"/>
												<xsl:value-of select="//character/items/item[name = $WName]/damage"/>
											</xsl:otherwise>
										</xsl:choose>
									</xsl:otherwise>
								</xsl:choose>
							</xsl:when>
							<xsl:otherwise>
								<xsl:variable name="WName" select="name"/>
								<xsl:value-of select="//character/items/item[name = $WName]/damage"/>
								<xsl:text>+(($S)*.5)</xsl:text>
							</xsl:otherwise>
						</xsl:choose>
					</xsl:element>
					<xsl:element name="critical">
						<xsl:value-of select="critical"/>
					</xsl:element>
					<xsl:element name="range">
						<xsl:value-of select="range"/>
					</xsl:element>
				</xsl:element>
			</xsl:when>
			<xsl:otherwise>
				<xsl:element name="weapon">
					<xsl:element name="w-name">
						<xsl:value-of select="name"/>
					</xsl:element>
					<xsl:element name="hand">
						<xsl:value-of select="use-type"/>
					</xsl:element>
					<xsl:element name="atk-mod">
						<xsl:choose>
							<xsl:when test="type = 'Ranged'">
								<xsl:variable name="WpnBns">
									<xsl:choose>
										<xsl:when test="substring(bonus,1,1) = '+'">
											<xsl:value-of select="substring-after(bonus,'+')"/>
										</xsl:when>
										<xsl:otherwise>
											<xsl:value-of select="bonus"/>
										</xsl:otherwise>
									</xsl:choose>
								</xsl:variable>
								<xsl:variable name="AtkNoDex" select="(number($WpnBns)-//character/attacks/ranged/modifiers/modifier[@name = 'ability']/@value)"/>
								<xsl:call-template name="GenerateAttackString">
									<xsl:with-param name="WpnBonus" select="$AtkNoDex"/>
									<xsl:with-param name="BaseBonus" select="substring-after(//character/attacks/base,'+')"/>
									<xsl:with-param name="KloogeStat" select="'$D'"/>
								</xsl:call-template>
							</xsl:when>
							<xsl:otherwise>
								<xsl:variable name="WpnBns">
									<xsl:choose>
										<xsl:when test="substring(bonus,1,1) = '+'">
											<xsl:value-of select="substring-after(bonus,'+')"/>
										</xsl:when>
										<xsl:otherwise>
											<xsl:value-of select="bonus"/>
										</xsl:otherwise>
									</xsl:choose>
								</xsl:variable>
								<xsl:variable name="AtkNoStr" select="(number($WpnBns)-//character/attacks/melee/modifiers/modifier[@name = 'ability']/@value)"/>
								<xsl:call-template name="GenerateAttackString">
									<xsl:with-param name="WpnBonus" select="$AtkNoStr"/>
									<xsl:with-param name="BaseBonus" select="substring-after(//character/attacks/base,'+')"/>
									<xsl:with-param name="KloogeStat" select="'$S'"/>
								</xsl:call-template>
							</xsl:otherwise>
						</xsl:choose>
					</xsl:element>
					<xsl:element name="damage">
						<xsl:choose>
							<xsl:when test="contains(name,'bow')">
								<xsl:choose>
									<xsl:when test="contains(name,'Cross')">
										<xsl:value-of select="damage"/>
									</xsl:when>
									<xsl:otherwise>
										<xsl:choose>
											<xsl:when test="contains(name, 'Str')">
												<xsl:variable name="TempStr" select="substring-before(name, 'Str')"/>
												<xsl:variable name="MaxStr" select="normalize-space(substring-after($TempStr, '+'))"/>
												<xsl:variable name="WName" select="name"/>
												<xsl:value-of select="//character/items/item[name = $WName]/damage"/>
												<xsl:text>+($S:</xsl:text>
												<xsl:value-of select="$MaxStr"/>
												<xsl:text>)</xsl:text>
											</xsl:when>
											<xsl:otherwise>
												<xsl:variable name="WName" select="name"/>
												<xsl:value-of select="//character/items/item[name = $WName]/damage"/>
											</xsl:otherwise>
										</xsl:choose>
									</xsl:otherwise>
								</xsl:choose>
							</xsl:when>
							<xsl:otherwise>
								<xsl:variable name="WName" select="name"/>
								<xsl:value-of select="//character/items/item[name = $WName]/damage"/>
								<xsl:text>$S</xsl:text>
							</xsl:otherwise>
						</xsl:choose>
					</xsl:element>
					<xsl:element name="critical">
						<xsl:value-of select="critical"/>
					</xsl:element>
					<xsl:element name="range">
						<xsl:value-of select="range"/>
					</xsl:element>
				</xsl:element>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	<xsl:template name="GenerateAttackString">
		<xsl:param name="WpnBonus"/>
		<xsl:param name="BaseBonus" select="'0'"/>
		<xsl:param name="KloogeStat" select="'$S'"/>
		<xsl:if test="$BaseBonus &gt; -1">
			<xsl:if test="$WpnBonus &gt; -1">
				<xsl:text>+</xsl:text>
			</xsl:if>
			<xsl:value-of select="$WpnBonus"/>
			<xsl:value-of select="$KloogeStat"/>
			<xsl:if test="$BaseBonus &gt; 5">
				<xsl:text>|</xsl:text>
				<xsl:call-template name="GenerateAttackString">
					<xsl:with-param name="WpnBonus" select="$WpnBonus - 5"/>
					<xsl:with-param name="BaseBonus" select="$BaseBonus - 5"/>
					<xsl:with-param name="KloogeStat" select="$KloogeStat"/>
				</xsl:call-template>
			</xsl:if>
		</xsl:if>
	</xsl:template>
</xsl:stylesheet>
