<?xml version="1.0" encoding="ISO-8859-1"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform">
	<!-- E-Tools Stylesheet for monster export to Klooge.Werks Ver 0.94 beta-->
	<!-- Written by Daedalus with liberal code snippets from Trevor Salla's "Monster Page" Stylesheets that shipped with E-Tools. -->
	<!-- Known Issues:
		Empty elements denote areas where I was unable to find the data.
		Proper indentation is not occuring in the final xml document.
	  
	To Do:
		Any other reasonable suggestions that come along. Play and learn ;-)
		 
	Fixed in 0.91
		*	Corrected a Base AC computational error.
	Fixed in 0.92
		*	Reference the 0.95 notes of the Character stylesheet.
	Fixed in 0.93
 		*	Fixed a problem where class names with spaces could cause invalid output xml tags.
 		*	Fixed output for natural weapons.
	Changed in 0.94
		*	Spell-like Abilities now show up on the Spells page.
		*	Added the IconSizeDivisor global for easy access.
		*	An empty tag is no longer output if spell resistance isn't present in the etools export.-->
	<xsl:import href="General String Functions"/>
	<xsl:import href="Stat Functions"/>
	<xsl:output method="xml" version="1.0" encoding="iso-8859-1" indent="yes"/>
	<xsl:template match="/">
		<xsl:variable name="IconSizeDivisor" select="'4'"/>
		<xsl:element name="char-sheet-3rd-ed">
		    <xsl:element name="portrait-image">
			<xsl:value-of select="/monster/portrait"/>
		    </xsl:element>
			<xsl:element name="personal-info">
				<xsl:element name="name">
					<xsl:value-of select="/monster/name"/>
				</xsl:element>
				<xsl:element name="player">
					<xsl:value-of select="/monster/player"/>
				</xsl:element>
				<xsl:element name="class">
					<xsl:value-of select="/monster/classes/class/name"/>
				</xsl:element>
				<xsl:element name="race">
					<!--
					<xsl:value-of select="/monster/race"/>
					-->
					<xsl:text>Monster</xsl:text>
				</xsl:element>
				<xsl:element name="type">
					<!--
					<xsl:value-of select="/monster/size/type"/>
					-->
					<xsl:value-of select="/monster/race"/>
				</xsl:element>
				<xsl:element name="size">
					<xsl:value-of select="/monster/size/category"/>
				</xsl:element>
				<xsl:element name="alignment">
					<xsl:value-of select="/monster/alignment/name"/>
				</xsl:element>
				<xsl:element name="age-sex">
				    <xsl:value-of select="/monster/age"/> / <xsl:value-of select="normalize-space(/monster/gender)"/>
				</xsl:element>
				<xsl:element name="height-weight">
					<xsl:value-of select="/monster/size/height"/> / <xsl:value-of select="normalize-space(/monster/size/weight)"/>
				</xsl:element>
				<xsl:element name="hair-eyes">
					<xsl:value-of select="/monster/hair"/> / <xsl:value-of select="normalize-space(/monster/eyes)"/>
				</xsl:element>
				<xsl:element name="speed">
					<xsl:for-each select="//monster/speeds/speed">
						<xsl:if test="position() &gt; 1">
							<xsl:text>, </xsl:text>
						</xsl:if>
						<xsl:choose>
							<xsl:when test="name = 'Base'">
								<xsl:text>Base: </xsl:text>
								<xsl:value-of select="value"/>
							</xsl:when>
							<xsl:otherwise>
								<xsl:value-of select="name"/>
								<xsl:text> </xsl:text>
								<xsl:value-of select="value"/>
							</xsl:otherwise>
						</xsl:choose>
					</xsl:for-each>
				</xsl:element>
				<xsl:element name="cr">
					<xsl:value-of select="/monster/challenge-rating"/>
				</xsl:element>
				<xsl:element name="hit-dice">
					<xsl:for-each select="/monster/hit-dice/hit-die">
						<xsl:value-of select="die"/>
						<xsl:value-of select="bonus"/>
						<!--
						<xsl:text>(</xsl:text>
						<xsl:value-of select="class"/>
						<xsl:text>)</xsl:text>
						-->
						<xsl:choose>
							<xsl:when test="position() != last()">
								<xsl:text>; </xsl:text>
							</xsl:when>
							<!--
							<xsl:otherwise>
								<xsl:text>, </xsl:text>
							</xsl:otherwise>
							-->
						</xsl:choose>
					</xsl:for-each>
				</xsl:element>
				<xsl:element name="experience">
					<xsl:value-of select="/monster/experience"/>
				</xsl:element>
				<xsl:element name="next-level">
					<xsl:variable name="totallevel" select="/monster/classes/total"/>
					<xsl:variable name="nextlevel" select="($totallevel * $totallevel + $totallevel) * 500"/>
					<xsl:value-of select="format-number($nextlevel, '########0')"/>
				</xsl:element>
			</xsl:element>
			<xsl:element name="level-info">
				<xsl:element name="level">
					<xsl:value-of select="/monster/classes/total"/>
				</xsl:element>
				<xsl:for-each select="/monster/classes/class">
					<xsl:variable name="currclass" select="translate(name, ' ','')"/>
					<xsl:variable name="classtag" select="concat($currclass, '-level')"/>
					<xsl:variable name="lclasstag">
						<xsl:call-template name="to-lower">
							<xsl:with-param name="text" select="$classtag"/>
						</xsl:call-template>
					</xsl:variable>
					<xsl:element name="{$lclasstag}">
						<xsl:value-of select="level"/>
					</xsl:element>
				</xsl:for-each>
			</xsl:element>
			<xsl:element name="combat">
				<xsl:element name="cur-hit-points">
					<xsl:value-of select="/monster/hit-points"/>
				</xsl:element>
				<xsl:element name="max-hit-points">
					<xsl:value-of select="/monster/hit-points"/>
				</xsl:element>
				<xsl:element name="subdual-damage">
					<xsl:text>0</xsl:text>
				</xsl:element>
                                <xsl:variable name="DamageReductionSQ">
                                        <xsl:for-each select="/monster/features/special-qualities/special-quality">
                                                <xsl:variable name="SQ" select="."/>
                                                <xsl:if test="starts-with($SQ, 'Damage Reduction')">
                                                        <xsl:value-of select="normalize-space(substring-before(substring-after($SQ, ': '), '/'))"/>
                                                </xsl:if>
                                        </xsl:for-each>
                                </xsl:variable>
                                <xsl:variable name="DamageReductionCF">
                                        <xsl:for-each select="/monster/features/class-features/class-feature/feature">
                                                <xsl:variable name="CF" select="."/>
                                                <xsl:if test="starts-with($CF, 'Damage Reduction')">
                                                        <xsl:value-of select="normalize-space(substring-before(substring-after($CF, 'Reduction '), '/'))"/>
                                                </xsl:if>
                                        </xsl:for-each>
                                </xsl:variable>
                                <xsl:choose>
                                        <xsl:when test="$DamageReductionSQ != ''">
                                                <xsl:choose>
                                                        <xsl:when test="$DamageReductionCF != ''">
                                                            <xsl:element name="damage-reduction">
                                                                <xsl:value-of select="$DamageReductionSQ + $DamageReductionCF"/>
                                                            </xsl:element>
                                                        </xsl:when>
                                                        <xsl:otherwise>
                                                            <xsl:element name="damage-reduction">
                                                                <xsl:value-of select="$DamageReductionSQ"/>
                                                            </xsl:element>
                                                        </xsl:otherwise>
                                                </xsl:choose>
                                        </xsl:when>
                                        <xsl:otherwise>
                                                <xsl:choose>
                                                        <xsl:when test="$DamageReductionCF != ''">
                                                            <xsl:element name="damage-reduction">
                                                                <xsl:value-of select="$DamageReductionCF"/>
                                                            </xsl:element>
                                                        </xsl:when>
                                                </xsl:choose>
                                        </xsl:otherwise>
                                </xsl:choose>
				<xsl:element name="base-attack-bonus">
					<xsl:value-of select="/monster/attacks/base"/>
				</xsl:element>
			</xsl:element>
			<xsl:element name="armor">
				<xsl:variable name="MaxDex">
					<xsl:variable name="TmpMaxDex">
						<xsl:variable name="LdCarried" select="//monster/load/carried"/>
						<xsl:variable name="LdMedium" select="normalize-space(substring-after(//monster/load/light, '-'))"/>
						<xsl:variable name="LdHeavy" select="normalize-space(substring-after(//monster/load/medium, '-'))"/>
						<xsl:choose>
							<xsl:when test="$LdCarried &gt; $LdHeavy">
								<xsl:value-of select="1"/>
							</xsl:when>
							<xsl:when test="$LdCarried &gt; $LdMedium">
								<xsl:value-of select="3"/>
							</xsl:when>
							<xsl:otherwise>
								<xsl:value-of select="5678"/>
							</xsl:otherwise>
						</xsl:choose>
					</xsl:variable>
					<xsl:variable name="ArmorMaxDex" select="//monster/equiped-items/armor/max-dex"/>
					<xsl:choose>
						<xsl:when test="$ArmorMaxDex != ''">
							<xsl:choose>
								<xsl:when test="$ArmorMaxDex &lt; $TmpMaxDex">
									<xsl:value-of select="$ArmorMaxDex"/>
								</xsl:when>
								<xsl:otherwise>
									<xsl:value-of select="$TmpMaxDex"/>
								</xsl:otherwise>
							</xsl:choose>
						</xsl:when>
						<xsl:otherwise>
							<xsl:value-of select="$TmpMaxDex"/>
						</xsl:otherwise>
					</xsl:choose>
				</xsl:variable>
				<xsl:element name="base-ac">
					<xsl:value-of select="(/monster/armor-class/modifiers/modifier[@name = 'base']/@value)"/>
				</xsl:element>
				<xsl:element name="armor-modifier">
					<xsl:value-of select="(/monster/armor-class/modifiers/modifier[@name = 'armor']/@value + /monster/armor-class/modifiers/modifier[@name = 'natural']/@value)"/>
				</xsl:element>
				<xsl:element name="shield-modifier">
					<xsl:value-of select="/monster/armor-class/modifiers/modifier[@name = 'shield']/@value"/>
				</xsl:element>
				<xsl:element name="dex-modifier">
					<xsl:text>$D</xsl:text>
				</xsl:element>
				<xsl:element name="size-modifier">
					<xsl:value-of select="/monster/armor-class/modifiers/modifier[@name = 'size']/@value"/>
				</xsl:element>
				<xsl:element name="misc-magic-modifier">
					<xsl:value-of select="/monster/armor-class/modifiers/modifier[@name = 'misc']/@value"/>
				</xsl:element>
				<xsl:element name="ac-final">
					<xsl:text>$A1$A2$A3$A4$A5$A6</xsl:text>
				</xsl:element>
				<xsl:for-each select="/monster/features/special-qualities/special-quality">
					<xsl:variable name="SQ" select="."/>
					<xsl:if test="starts-with($SQ, 'Spell Resistance')">
						<xsl:element name="spell-resistance">
							<xsl:value-of select="substring-after($SQ, ': ')"/>
						</xsl:element>
					</xsl:if>
				</xsl:for-each>
				<xsl:element name="touch-ac">
				    <xsl:text>$A1$A4$A5$A6</xsl:text>
				</xsl:element>
				<xsl:element name="flat-footed-ac">
					<xsl:text>$A1$A2$A3$A5$A6</xsl:text>
				</xsl:element>
			</xsl:element>
			<xsl:element name="abilities">
				<xsl:for-each select="/monster/abilities/ability">
					<xsl:variable name="currabil" select="abbr"/>
					<xsl:variable name="lcurrabil">
						<xsl:call-template name="to-lower">
							<xsl:with-param name="text" select="$currabil"/>
						</xsl:call-template>
					</xsl:variable>
					<xsl:element name="{$lcurrabil}">
						<xsl:value-of select="base"/>
					</xsl:element>
					<xsl:element name="{concat($lcurrabil, '-mod')}">
						<xsl:value-of select="modifier"/>
					</xsl:element>
				</xsl:for-each>
			</xsl:element>
			<xsl:element name="saving-throws">
				<xsl:for-each select="/monster/saving-throws/saving-throw">
					<xsl:variable name="currsave" select="abbr"/>
					<xsl:variable name="lcurrsave">
						<xsl:call-template name="to-lower">
							<xsl:with-param name="text" select="$currsave"/>
						</xsl:call-template>
					</xsl:variable>
					<xsl:element name="{$lcurrsave}">
						<xsl:variable name="saveval" select="sum(modifiers/modifier[@name != 'misc']/@value)-(modifiers/modifier[@name = 'ability']/@value)"/>
						<xsl:if test="$saveval >= 0">
							<xsl:text>+</xsl:text>
						</xsl:if>
						<xsl:value-of select="$saveval"/>
						<xsl:choose>
							<xsl:when test="ability = 'Str'">
								<xsl:text>$S</xsl:text>
							</xsl:when>
							<xsl:when test="ability = 'Dex'">
								<xsl:text>$D</xsl:text>
							</xsl:when>
							<xsl:when test="ability = 'Con'">
								<xsl:text>$C</xsl:text>
							</xsl:when>
							<xsl:when test="ability = 'Int'">
								<xsl:text>$I</xsl:text>
							</xsl:when>
							<xsl:when test="ability = 'Wis'">
								<xsl:text>$W</xsl:text>
							</xsl:when>
							<xsl:when test="ability = 'Cha'">
								<xsl:text>$CH</xsl:text>
							</xsl:when>
						</xsl:choose>
					</xsl:element>
				</xsl:for-each>
				<xsl:element name="init">
					<xsl:variable name="initval" select="sum(/monster/initiative/modifiers/modifier[@name != 'misc']/@value)-(/monster/initiative/modifiers/modifier[@name = 'ability']/@value)"/>
					<xsl:if test="$initval >= 0">
						<xsl:text>+</xsl:text>
					</xsl:if>
					<xsl:value-of select="$initval"/>
					<xsl:text>$D</xsl:text>
				</xsl:element>
			</xsl:element>
			<xsl:element name="misc-attributes">
				<xsl:element name="threatened-area">
					<xsl:value-of select="/monster/size/reach"/>
				</xsl:element>
				<xsl:element name="icon-size">
					<xsl:variable name="IcnXSize" select="/monster/size/face/x"/>
					<xsl:variable name="IcnYSize" select="/monster/size/face/y"/>
					<xsl:variable name="IcnSize" select="($IcnXSize + $IcnYSize) div $IconSizeDivisor"/>
					<xsl:value-of select="$IcnSize"/>
				</xsl:element>
			</xsl:element>
			<xsl:element name="racial-traits">
				<xsl:for-each select="/monster/features/special-attacks/special-attack">
					<xsl:element name="racial-trait">
						<xsl:element name="trait-name">
							<xsl:text>Special Attack: </xsl:text>
							<xsl:value-of select="name"/>
						</xsl:element>
					</xsl:element>
				</xsl:for-each>
				<xsl:for-each select="/monster/features/special-qualities/special-quality">
					<xsl:element name="racial-trait">
						<xsl:element name="trait-name">
							<xsl:text>Special Quality: </xsl:text>
							<xsl:value-of select="."/>
						</xsl:element>
					</xsl:element>
				</xsl:for-each>
			</xsl:element>
			<xsl:element name="languages">
				<xsl:for-each select="/monster/languages/language">
					<xsl:sort select="." order="ascending"/>
					<xsl:element name="language">
						<xsl:element name="lang-name">
							<xsl:value-of select="."/>
						</xsl:element>
					</xsl:element>
				</xsl:for-each>
			</xsl:element>
			<xsl:element name="feats">
				<xsl:for-each select="/monster/features/feats/feat">
					<xsl:sort select="name" order="ascending"/>
					<xsl:element name="feat">
						<xsl:element name="feat-name">
							<xsl:value-of select="name"/>
						</xsl:element>
					</xsl:element>
				</xsl:for-each>
			</xsl:element>
			<xsl:element name="skills">
				<xsl:for-each select="/monster/skills/skill">
					<xsl:sort select="name" order="ascending"/>
					<xsl:element name="skill">
						<xsl:element name="skill-name">
							<xsl:value-of select="name"/>
						</xsl:element>
						<xsl:element name="total">
						    <xsl:text>$XA$XB$XC</xsl:text>
						</xsl:element>
						<xsl:element name="rank">
						    <xsl:value-of select="modifiers/modifier[@name = 'rank']/@value"/>
						</xsl:element>
						<xsl:element name="modifier">
						    <xsl:value-of select="modifiers/modifier[@name = 'ability']/@value"/>
						</xsl:element>
						<xsl:element name="misc">
						    <xsl:value-of select="modifiers/modifier[@name = 'misc']/@value"/>
						</xsl:element>
						<xsl:element name="ability">
						    <xsl:value-of select="ability"/>
						</xsl:element>
					</xsl:element>
				</xsl:for-each>
			</xsl:element>
			<xsl:element name="weapons">
			<!-- Heavily Reworked for differentiation between Natural and Equipped Weapons -->
				<xsl:for-each select="//monster/equiped-items/weapons">
					<xsl:for-each select="weapon">
						<xsl:variable name="CurrWeapName" select="name"/>
						<xsl:choose>
						    <!--If Name is in the Items list then it is not a natural weapon.-->
							<xsl:when test="//monster/items/item[name = $CurrWeapName]/type != ''">
								<xsl:choose>
									<xsl:when test="position() = 1">
										<xsl:call-template name="GenerateWeaponData">
											<xsl:with-param name="IsOffHand" select="'False'"/>
										</xsl:call-template>
									</xsl:when>
									<xsl:otherwise>
										<xsl:choose>
											<xsl:when test="//monster/options/text-offhand-indication = 1">
												<xsl:call-template name="GenerateWeaponData">
													<xsl:with-param name="IsOffHand" select="'True'"/>
												</xsl:call-template>
											</xsl:when>
											<xsl:otherwise>
												<xsl:call-template name="GenerateWeaponData">
													<xsl:with-param name="IsOffHand" select="'False'"/>
												</xsl:call-template>
											</xsl:otherwise>
										</xsl:choose>
									</xsl:otherwise>
								</xsl:choose>
							</xsl:when>
							<xsl:otherwise>
								<xsl:element name="weapon">
									<xsl:element name="w-name">
										<xsl:value-of select="$CurrWeapName"/>
									</xsl:element>
									<xsl:element name="hand">
										<xsl:choose>
											<xsl:when test="use-type != ''">
												<xsl:value-of select="use-type"/>
											</xsl:when>
											<xsl:otherwise>
												<xsl:text>Natural</xsl:text>
											</xsl:otherwise>
										</xsl:choose>
									</xsl:element>
									<xsl:element name="atk-mod">
										<xsl:variable name="NumAttTest" select="substring-before($CurrWeapName, ' ')"/>
										<xsl:variable name="CurrAttBonus" select="(substring(bonus,2,string-length(bonus)))-(//monster/attacks/melee/modifiers/modifier[@name = 'ability']/@value)"/>
										<xsl:variable name="KWStat">
											<xsl:choose>
												<xsl:when test="type = 'Melee'">
													<xsl:text>$S</xsl:text>
												</xsl:when>
												<xsl:otherwise>
													<xsl:text>$D</xsl:text>
												</xsl:otherwise>
											</xsl:choose>
										</xsl:variable>
										<xsl:choose>
											<xsl:when test="number($NumAttTest) != 'NaN' and $NumAttTest != ''">
												<xsl:call-template name="GenerateNaturalAttackString">
													<xsl:with-param name="NumAttacks" select="number($NumAttTest)"/>
													<xsl:with-param name="AttackBonus" select="$CurrAttBonus"/>
													<xsl:with-param name="KloogeStat" select="$KWStat"/>
												</xsl:call-template>
											</xsl:when>
											<xsl:otherwise>
												<xsl:call-template name="GenerateNaturalAttackString">
													<xsl:with-param name="NumAttacks" select="1"/>
													<xsl:with-param name="AttackBonus" select="$CurrAttBonus"/>
													<xsl:with-param name="KloogeStat" select="$KWStat"/>
												</xsl:call-template>
											</xsl:otherwise>
										</xsl:choose>
									</xsl:element>
									<xsl:element name="damage">
										<xsl:value-of select="damage"/>
										<xsl:text>$S</xsl:text>
										<!--  This entire block makes no sense to me.  Why compute
											  the strenth bonus, add it to damage and then subtract
											  it back off???
										<xsl:variable name="SMod">
											<xsl:choose>
												<xsl:when test="substring-after(//monster/abilities/ability[name = 'Strength']/modifier, '+') != ''">
													<xsl:value-of select="substring-after(//monster/abilities/ability[name = 'Strength']/modifier, '+')"/>
												</xsl:when>
												<xsl:otherwise>
													<xsl:value-of select="//monster/abilities/ability[name = 'Strength']/modifier"/>
												</xsl:otherwise>
											</xsl:choose>
										</xsl:variable>
										<xsl:choose>
											<xsl:when test="position() = 1">
												<xsl:text>+($S-</xsl:text>
												<xsl:value-of select="$SMod"/>
												<xsl:text>)</xsl:text>
											</xsl:when>
											<xsl:otherwise>
												<xsl:choose>
													<xsl:when test="//monster/options/text-offhand-indication = 1">
														<xsl:text>+(($S*.5)-</xsl:text>
														<xsl:value-of select="floor($SMod div 2)"/>
														<xsl:text>)</xsl:text>
													</xsl:when>
													<xsl:otherwise>
														<xsl:text>+($S-</xsl:text>
														<xsl:value-of select="$SMod"/>
														<xsl:text>)</xsl:text>
													</xsl:otherwise>
												</xsl:choose>
											</xsl:otherwise>
										</xsl:choose>
										-->
									</xsl:element>
									<xsl:element name="critical">
										<xsl:variable name="TmpCrit" select="critical"/>
										<xsl:choose>
											<xsl:when test="$TmpCrit != ''">
												<xsl:value-of select="$TmpCrit"/>
											</xsl:when>
											<xsl:otherwise>
												<xsl:text>x2</xsl:text>
											</xsl:otherwise>
										</xsl:choose>
									</xsl:element>
									<xsl:element name="range">
										<xsl:value-of select="range"/>
									</xsl:element>
								</xsl:element>
							</xsl:otherwise>
						</xsl:choose>
					</xsl:for-each>
				</xsl:for-each>
			</xsl:element>
			<xsl:element name="equipment">
				<xsl:for-each select="/monster/items/item">
					<xsl:sort select="type" order="ascending"/>
					<xsl:element name="item">
						<xsl:element name="equip-name">
							<xsl:value-of select="type"/>
							<xsl:text>: </xsl:text>
							<xsl:value-of select="name"/>
						</xsl:element>
						<xsl:element name="desc">
							<xsl:text>Weight: </xsl:text>
							<xsl:value-of select="weight"/>
						</xsl:element>
					</xsl:element>
				</xsl:for-each>
			</xsl:element>
			<xsl:element name="wealth">
				<xsl:for-each select="/monster/currency/*">
				    <xsl:if test="name() != 'value'">
					<xsl:element name="coin">
						<xsl:element name="type">
							<xsl:value-of select="name()"/>
						</xsl:element>
						<xsl:element name="carried">
							<xsl:value-of select="."/>
						</xsl:element>
					</xsl:element>
				    </xsl:if>
				</xsl:for-each>
			</xsl:element>
			<xsl:for-each select="/monster/features/special-attacks/special-attack">
			<xsl:if test="contains(name,'Spell-like')">
				<xsl:element name="magic-abilities">
					<xsl:for-each select="spell">
					<xsl:sort select="name" order="ascending"/>
						<xsl:element name="spell-levels">
							<xsl:element name="level">
								<xsl:value-of select="concat(name, '(Sp)')"/>
							</xsl:element>
							<xsl:choose>
								<xsl:when test="times-per-day = 'At Will'">
									<xsl:element name="max">
										<xsl:value-of select="times-per-day"/>
									</xsl:element>
									<xsl:element name="current">
										<xsl:value-of select="1"/>
									</xsl:element>
								</xsl:when>
								<xsl:otherwise>
									<xsl:element name="max">
										<xsl:value-of select="times-per-day"/>
									</xsl:element>
									<xsl:element name="current">
										<xsl:value-of select="times-per-day"/>
									</xsl:element>
								</xsl:otherwise>
							</xsl:choose>
						</xsl:element>
					</xsl:for-each>
				</xsl:element>
				<xsl:element name="spell-dc">
					<xsl:text>$Ch</xsl:text>
				</xsl:element>
				<xsl:element name="spells">
					<xsl:for-each select="spell">
					<xsl:sort select="name" order="ascending"/>
						<xsl:element name="spell">
							<xsl:element name="spell-name">
								<xsl:value-of select="concat(name, '(Sp)')"/>
							</xsl:element>
							<xsl:element name="level">
								<xsl:value-of select="caster-level"/>
							</xsl:element>
							<xsl:element name="cast-level">
								<xsl:value-of select="concat(name, '(Sp)')"/>
							</xsl:element>
							<xsl:element name="expr">
								<xsl:value-of select="'{0}'"/>
							</xsl:element>
							<xsl:element name="num-memorized">
								<xsl:value-of select="'--'"/>
							</xsl:element>
							<xsl:element name="cost">
								<xsl:choose>
									<xsl:when test="times-per-day = 'At Will'">
										<xsl:value-of select="'0'"/>
									</xsl:when>
									<xsl:otherwise>
										<xsl:value-of select="'1'"/>
									</xsl:otherwise>
								</xsl:choose>
							</xsl:element>
							<xsl:element name="effect"/>
						</xsl:element>
					</xsl:for-each>
					</xsl:element>
				</xsl:if>
			</xsl:for-each>
			<xsl:element name="notes">
				<xsl:element name="note">
					<xsl:element name="title">
						<xsl:value-of select="'Load Information'"/>
					</xsl:element>
					<xsl:element name="text">
						<xsl:for-each select="/monster/load/*">
							<xsl:value-of select="name()"/>
							<xsl:text>: </xsl:text>
							<xsl:value-of select="."/>
							<xsl:value-of select="$cr"/>
						</xsl:for-each>
					</xsl:element>
				</xsl:element>
				<xsl:for-each select="/monster/notes/*">
				    <xsl:if test="string-length() &gt; 0">
					<xsl:element name="note">
						<xsl:element name="title">
							<xsl:value-of select="name()"/>
						</xsl:element>
						<xsl:element name="text">
							<xsl:value-of select="."/>
						</xsl:element>
					</xsl:element>
				    </xsl:if>
				</xsl:for-each>
			</xsl:element>
		</xsl:element>
	</xsl:template>
	<xsl:template name="GenerateWeaponData">
		<xsl:param name="IsOffHand"/>
		<xsl:choose>
			<xsl:when test="$IsOffHand = 'True'">
				<xsl:element name="weapon">
					<xsl:element name="w-name">
						<xsl:value-of select="name"/>
						<xsl:text> (OH)</xsl:text>
					</xsl:element>
					<xsl:element name="hand">
						<xsl:value-of select="use-type"/>
					</xsl:element>
					<xsl:element name="atk-mod">
						<xsl:choose>
							<xsl:when test="type = 'Ranged'">
								<xsl:variable name="WpnBns">
									<xsl:choose>
										<xsl:when test="substring(bonus,1,1) = '+'">
											<xsl:value-of select="substring-after(bonus,'+')"/>
										</xsl:when>
										<xsl:otherwise>
											<xsl:value-of select="bonus"/>
										</xsl:otherwise>
									</xsl:choose>
								</xsl:variable>
								<xsl:variable name="AtkNoDex" select="(number($WpnBns)-//monster/attacks/ranged/modifiers/modifier[@name = 'ability']/@value)"/>
								<xsl:call-template name="GenerateAttackString">
									<xsl:with-param name="WpnBonus" select="$AtkNoDex"/>
									<xsl:with-param name="BaseBonus" select="'0'"/>
									<xsl:with-param name="KloogeStat" select="'$D'"/>
								</xsl:call-template>
							</xsl:when>
							<xsl:otherwise>
								<xsl:variable name="WpnBns">
									<xsl:choose>
										<xsl:when test="substring(bonus,1,1) = '+'">
											<xsl:value-of select="substring-after(bonus,'+')"/>
										</xsl:when>
										<xsl:otherwise>
											<xsl:value-of select="bonus"/>
										</xsl:otherwise>
									</xsl:choose>
								</xsl:variable>
								<xsl:variable name="AtkNoStr" select="(number($WpnBns)-//monster/attacks/melee/modifiers/modifier[@name = 'ability']/@value)"/>
								<xsl:call-template name="GenerateAttackString">
									<xsl:with-param name="WpnBonus" select="$AtkNoStr"/>
									<xsl:with-param name="BaseBonus" select="'0'"/>
									<xsl:with-param name="KloogeStat" select="'$S'"/>
								</xsl:call-template>
							</xsl:otherwise>
						</xsl:choose>
					</xsl:element>
					<xsl:element name="damage">
						<xsl:choose>
							<xsl:when test="contains(name,'bow')">
								<xsl:choose>
									<xsl:when test="contains(name,'Cross')">
										<xsl:value-of select="damage"/>
									</xsl:when>
									<xsl:otherwise>
										<xsl:choose>
											<xsl:when test="contains(name, 'Str')">
												<xsl:variable name="TempStr" select="substring-before(name, 'Str')"/>
												<xsl:variable name="MaxStr" select="normalize-space(substring-after($TempStr, '+'))"/>
												<xsl:variable name="WName" select="name"/>
												<xsl:value-of select="//monster/items/item[name = $WName]/damage"/>
												<xsl:text>+(($S:</xsl:text>
												<xsl:value-of select="$MaxStr"/>
												<xsl:text>)*.5)</xsl:text>
											</xsl:when>
											<xsl:otherwise>
												<xsl:variable name="WName" select="name"/>
												<xsl:value-of select="//monster/items/item[name = $WName]/damage"/>
											</xsl:otherwise>
										</xsl:choose>
									</xsl:otherwise>
								</xsl:choose>
							</xsl:when>
							<xsl:otherwise>
								<xsl:variable name="WName" select="name"/>
								<xsl:value-of select="//monster/items/item[name = $WName]/damage"/>
								<xsl:text>+(($S)*.5)</xsl:text>
							</xsl:otherwise>
						</xsl:choose>
					</xsl:element>
					<xsl:element name="critical">
						<xsl:value-of select="critical"/>
					</xsl:element>
					<xsl:element name="range">
						<xsl:value-of select="range"/>
					</xsl:element>
				</xsl:element>
			</xsl:when>
			<xsl:otherwise>
				<xsl:element name="weapon">
					<xsl:element name="w-name">
						<xsl:value-of select="name"/>
					</xsl:element>
					<xsl:element name="hand">
						<xsl:value-of select="use-type"/>
					</xsl:element>
					<xsl:element name="atk-mod">
						<xsl:choose>
							<xsl:when test="type = 'Ranged'">
								<xsl:variable name="WpnBns">
									<xsl:choose>
										<xsl:when test="substring(bonus,1,1) = '+'">
											<xsl:value-of select="substring-after(bonus,'+')"/>
										</xsl:when>
										<xsl:otherwise>
											<xsl:value-of select="bonus"/>
										</xsl:otherwise>
									</xsl:choose>
								</xsl:variable>
								<xsl:variable name="AtkNoDex" select="(number($WpnBns)-//monster/attacks/ranged/modifiers/modifier[@name = 'ability']/@value)"/>
								<xsl:call-template name="GenerateAttackString">
									<xsl:with-param name="WpnBonus" select="$AtkNoDex"/>
									<xsl:with-param name="BaseBonus" select="substring-after(//monster/attacks/base,'+')"/>
									<xsl:with-param name="KloogeStat" select="'$D'"/>
								</xsl:call-template>
							</xsl:when>
							<xsl:otherwise>
								<xsl:variable name="WpnBns">
									<xsl:choose>
										<xsl:when test="substring(bonus,1,1) = '+'">
											<xsl:value-of select="substring-after(bonus,'+')"/>
										</xsl:when>
										<xsl:otherwise>
											<xsl:value-of select="bonus"/>
										</xsl:otherwise>
									</xsl:choose>
								</xsl:variable>
								<xsl:variable name="AtkNoStr" select="(number($WpnBns)-//monster/attacks/melee/modifiers/modifier[@name = 'ability']/@value)"/>
								<xsl:call-template name="GenerateAttackString">
									<xsl:with-param name="WpnBonus" select="$AtkNoStr"/>
									<xsl:with-param name="BaseBonus" select="substring-after(//monster/attacks/base,'+')"/>
									<xsl:with-param name="KloogeStat" select="'$S'"/>
								</xsl:call-template>
							</xsl:otherwise>
						</xsl:choose>
					</xsl:element>
					<xsl:element name="damage">
						<xsl:choose>
							<xsl:when test="contains(name,'bow')">
								<xsl:choose>
									<xsl:when test="contains(name,'Cross')">
										<xsl:value-of select="damage"/>
									</xsl:when>
									<xsl:otherwise>
										<xsl:choose>
											<xsl:when test="contains(name, 'Str')">
												<xsl:variable name="TempStr" select="substring-before(name, 'Str')"/>
												<xsl:variable name="MaxStr" select="normalize-space(substring-after($TempStr, '+'))"/>
												<xsl:variable name="WName" select="name"/>
												<xsl:value-of select="//monster/items/item[name = $WName]/damage"/>
												<xsl:text>+($S:</xsl:text>
												<xsl:value-of select="$MaxStr"/>
												<xsl:text>)</xsl:text>
											</xsl:when>
											<xsl:otherwise>
												<xsl:variable name="WName" select="name"/>
												<xsl:value-of select="//monster/items/item[name = $WName]/damage"/>
											</xsl:otherwise>
										</xsl:choose>
									</xsl:otherwise>
								</xsl:choose>
							</xsl:when>
							<xsl:otherwise>
								<xsl:variable name="WName" select="name"/>
								<xsl:value-of select="//monster/items/item[name = $WName]/damage"/>
								<xsl:text>$S</xsl:text>
							</xsl:otherwise>
						</xsl:choose>
					</xsl:element>
					<xsl:element name="critical">
						<xsl:value-of select="critical"/>
					</xsl:element>
					<xsl:element name="range">
						<xsl:value-of select="range"/>
					</xsl:element>
				</xsl:element>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	<xsl:template name="GenerateAttackString">
		<xsl:param name="WpnBonus"/>
		<xsl:param name="BaseBonus" select="'0'"/>
		<xsl:param name="KloogeStat" select="'$S'"/>
		<xsl:if test="$BaseBonus &gt; -1">
			<xsl:if test="$WpnBonus &gt; -1">
				<xsl:text>+</xsl:text>
			</xsl:if>
			<xsl:value-of select="$WpnBonus"/>
			<xsl:value-of select="$KloogeStat"/>
			<xsl:if test="$BaseBonus &gt; 5">
				<xsl:text>|</xsl:text>
				<xsl:call-template name="GenerateAttackString">
					<xsl:with-param name="WpnBonus" select="$WpnBonus - 5"/>
					<xsl:with-param name="BaseBonus" select="$BaseBonus - 5"/>
					<xsl:with-param name="KloogeStat" select="$KloogeStat"/>
				</xsl:call-template>
			</xsl:if>
		</xsl:if>
	</xsl:template>
	<xsl:template name="GenerateNaturalAttackString">
		<xsl:param name="NumAttacks" select="0"/>
		<xsl:param name="AttackBonus"/>
		<xsl:param name="KloogeStat" select="'$S'"/>
		<xsl:if test="$NumAttacks &gt; 0">
		    <xsl:if test="$AttackBonus &gt; -1">
		    	<xsl:text>+</xsl:text>
		    </xsl:if>
			<xsl:value-of select="$AttackBonus"/>
			<xsl:value-of select="$KloogeStat"/>
			<xsl:if test="$NumAttacks &gt; 1">
				<xsl:text>|</xsl:text>
			</xsl:if>
			<xsl:call-template name="GenerateNaturalAttackString">
				<xsl:with-param name="NumAttacks" select="$NumAttacks - 1"/>
				<xsl:with-param name="AttackBonus" select="$AttackBonus"/>
				<xsl:with-param name="KloogeStat" select="$KloogeStat"/>
			</xsl:call-template>
		</xsl:if>
	</xsl:template>
</xsl:stylesheet>
